'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
function getReadManyInputQueryString(schema) {
  var variables = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var paginationStrategy = schema.paginationStrategy,
      sortStrategy = schema.sortStrategy,
      searchStrategy = schema.searchStrategy;

  var inputPairs = [];
  if (paginationStrategy) {
    inputPairs.push({ key: 'skip', value: variables.skip });
    inputPairs.push({ key: 'limit', value: variables.limit });
  }

  if (sortStrategy) {
    // note: the replace is used to remove quotes from properties
    var sortValue = [].concat(variables.sort);
    var shouldAddDefaultSort = sortStrategy.type === 'SINGLE' && sortValue.length === 0 && sortStrategy.defaultSortField;
    if (shouldAddDefaultSort) {
      sortValue.push({
        field: sortStrategy.defaultSortField,
        order: 'ASC'
      });
    }
    inputPairs.push({
      key: 'sort',
      value: JSON.stringify(sortValue).replace(/"([^(")"]+)":/g, "$1:")
    });
  }

  if (searchStrategy) {
    inputPairs.push({
      key: 'search',
      value: '"' + variables.search + '"'
    });
  }

  if (Object.keys(inputPairs).length === 0) {
    return '';
  }

  var string = inputPairs.map(function (_ref) {
    var key = _ref.key,
        value = _ref.value;

    return [key, value].join(': ');
  }).join(', ');

  return '(' + string + ')';
}

exports.default = getReadManyInputQueryString;