'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setAccessToken = exports.accessToken = undefined;
exports.default = StateHOF;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _redux = require('redux');

var _reactApollo = require('react-apollo');

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var existingAccessToken = process.browser ? window.localStorage.getItem('accessToken') : null;

function accessToken() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : existingAccessToken;
  var action = arguments[1];

  switch (action.type) {
    case 'SET_ACCESS_TOKEN':
      return action.accessToken;
    default:
      return state;
  }
}

function setAccessToken(accessToken) {
  if (accessToken) {
    window.localStorage.setItem('accessToken', accessToken);
  } else {
    window.localStorage.removeItem('accessToken');
  }
  return {
    type: 'SET_ACCESS_TOKEN',
    accessToken: accessToken
  };
}

function createProvider(_ref) {
  var graphqlUrl = _ref.config.graphqlUrl;

  var networkInterface = (0, _reactApollo.createNetworkInterface)({
    uri: graphqlUrl
  });

  networkInterface.use([{
    applyMiddleware: function applyMiddleware(req, next) {
      if (!req.options.headers) {
        req.options.headers = {}; // Create the header object if needed.
      }
      req.options.headers['authorization'] = localStorage.getItem('accessToken') || null;
      next();
    }
  }]);

  networkInterface.useAfter([{
    applyAfterware: function applyAfterware(_ref2, next) {
      var _this = this;

      var response = _ref2.response;
      return _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var text, firstErrorMessage;
        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.next = 2;
                return response.clone().text();

              case 2:
                text = _context.sent;
                firstErrorMessage = (0, _lodash.get)(JSON.parse(text), 'errors.0.message');

                if (firstErrorMessage === 'not-authorized') {
                  store.dispatch(setAccessToken(null));
                }
                next();

              case 6:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, _this);
      }))();
    }
  }]);

  var client = new _reactApollo.ApolloClient({
    networkInterface: networkInterface
  });

  var initialState = {};

  // If you are using the devToolsExtension, you can add it here also
  var reduxDevtoolMiddleware = typeof window.__REDUX_DEVTOOLS_EXTENSION__ !== 'undefined' ? window.__REDUX_DEVTOOLS_EXTENSION__() : function (f) {
    return f;
  };

  var store = (0, _redux.createStore)((0, _redux.combineReducers)({
    apollo: client.reducer(),
    accessToken: accessToken
  }), initialState, (0, _redux.compose)((0, _redux.applyMiddleware)(client.middleware()), reduxDevtoolMiddleware));

  return function (props) {
    return _react2.default.createElement(
      _reactApollo.ApolloProvider,
      { store: store, client: client },
      props.children
    );
  };
}

var createProviderOnce = (0, _lodash.once)(createProvider);

function StateHOF(Component) {
  return function (props) {
    var Provider = createProviderOnce(props);
    return _react2.default.createElement(
      Provider,
      null,
      _react2.default.createElement(Component, props)
    );
  };
}

exports.accessToken = accessToken;
exports.setAccessToken = setAccessToken;